part of 'profile_bloc.dart';

abstract class ProfileState extends Equatable {
  const ProfileState();
  
  @override
  List<Object> get props => [];
}

class ProfileInitial extends ProfileState {}

class ProfileLoaded extends ProfileState{
  final ProfileInformation profileInformation;
    const ProfileLoaded({required this.profileInformation});
  @override
  List<Object> get props => [profileInformation];
}

class ProfileErrorState extends ProfileState{
  final String mesage;
  const ProfileErrorState({required this.mesage});
    @override
  List<Object> get props => [mesage];
}

class ProfileLoading extends ProfileState{

}

class EligibilityLoaded extends ProfileState{
  final List<EligibityCert> eligibilities;
  const EligibilityLoaded({required this.eligibilities});
   @override
  List<Object> get props => [eligibilities];
}

class EditEligibilityState extends ProfileState{
  final EligibityCert eligibityCert;
  final List<EligibilityList> eligibilities;
  final List<country.Country> countries;
  final List<region.Region> regions;
  const EditEligibilityState({required this.eligibityCert, required this.eligibilities, required this.countries, required this.regions});
   @override
  List<Object> get props => [eligibityCert];
}
